BaseBandModulationParams

Struct BaseBandModulationParams 

pub struct BaseBandModulationParams {
    pub sf: SpreadingFactor,
    pub bw: Bandwidth,
    pub cr: CodingRate,
    pub ldro: bool,
    /* private fields */
}
LoRa modulation parameters barring frequency

Fields

sf: SpreadingFactorbw: Bandwidthcr: CodingRateldro: bool

low data rate optimization, see SX127x datasheet section 4.1.1.6

Implementations

Source

impl BaseBandModulationParams

pub const fn new(sf: SpreadingFactor, bw: Bandwidth, cr: CodingRate) -> Self

Create a set of parameters, possible forcing low data rate optimization on or off. Low data rate optimization is determined automatically based on sf and bw according to Semtech’s datasheets for SX126x/SX127x (enabled if symbol length is >= 16.38ms)

pub const fn delay_in_symbols(&self, delay_in_ms: u32) -> u16

pub const fn symbols_to_ms(&self, symbols: u32) -> u32

pub const fn time_on_air_us( &self, preamble: Option<u8>, explicit_header: bool, len: u8, ) -> u32

Calculates time on air for a given payload and modulation parameters. If preamble is None, the whole preamble including syncword is excluded from calculation.